Obsidian WikiLink ([[...]]) extraction.
Links inside fenced code blocks and inline code spans are ignored.
Structs
- Wiki
Link - Parsed Obsidian WikiLink representation.
- Wiki
Link Span - A WikiLink with byte offsets into the source markdown (
startinclusive,endexclusive).
Functions
- extract_
wikilink_ spans - Extract WikiLinks with absolute byte spans (for safe in-place rewrites).
- extract_
wikilinks - Extract all WikiLinks from markdown, skipping fenced and inline code.